# python-mssev

Calculates ARMSS (age-related multiple sclerosis severity) and both local and global MSSS (multiple sclerosis severity score). This package is a port of [ms.sev](https://rdrr.io/cran/ms.sev/).<